@@ -9,6 +9,9 @@ use std::{
     fmt::Display
 };
 
+mod loading;
+pub use loading::*;
+
 // to do: multiline button and table view
 
 /// Horizontal divider view
